@@ -245,27 +245,27 @@ static GnomeUIInfo menu_defaults[] = {
 	/*
 	 * The "Game" menu
 	 */
-        { GNOME_APP_UI_ITEM, N_("_New game"),
+        { GNOME_APP_UI_ITEM, N_("_New Game"),
           N_("Start a new game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           GNOME_KEY_NAME_NEW_GAME,  GNOME_KEY_MOD_NEW_GAME, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Pause game"),
+        { GNOME_APP_UI_ITEM, N_("_Pause Game"),
           N_("Pause the game"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_TIMER_STOP,
           GNOME_KEY_NAME_PAUSE_GAME,  GNOME_KEY_MOD_PAUSE_GAME, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Restart game"),
+        { GNOME_APP_UI_ITEM, N_("_Restart Game"),
           N_("Restart the game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           0,  0, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Undo move"),
+        { GNOME_APP_UI_ITEM, N_("_Undo Move"),
           N_("Undo the last move"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO,
           GNOME_KEY_NAME_UNDO_MOVE,  GNOME_KEY_MOD_UNDO_MOVE, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Redo move"),
+        { GNOME_APP_UI_ITEM, N_("_Redo Move"),
           N_("Redo the undone move"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REDO,
@@ -281,7 +281,7 @@ static GnomeUIInfo menu_defaults[] = {
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_SCORES,
           0,  (GdkModifierType) 0, NULL },
-        { GNOME_APP_UI_ITEM, N_("_End game"),
+        { GNOME_APP_UI_ITEM, N_("_End Game"),
           N_("End the current game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
@@ -1570,7 +1570,7 @@ gnome_app_create_menus_interp (GnomeApp *app, GnomeUIInfo *uiinfo,
  * function.
  *
  * Identical to gnome_app_create_menus(), except that @user_data is passed to
- * all the callback funtions when signals are emitted.
+ * all the callback functions when signals are emitted.
  **/
 
 void
@@ -2549,6 +2549,9 @@ global_menu_item_activated (GtkWidget *item)
 
 }
 
+/* Welcome to Hack City, population: gnome-app-helper */
+#define _(x) dgettext (GETTEXT_PACKAGE, x)
+
 static void
 create_and_popup_toolbar_menu (GdkEventButton *event)
 {
@@ -2628,7 +2631,7 @@ create_and_popup_toolbar_menu (GdkEventButton *event)
 		g_assert_not_reached ();
 	}
 
-	global = g_strdup_printf (_("Use desktop default (%s)"),
+	global = g_strdup_printf (_("Use Desktop Default (%s)"),
 				  str);
 	global_item = gtk_radio_menu_item_new_with_label (group, global);
 	g_signal_connect (global_item, "activate",
@@ -2679,6 +2682,10 @@ create_and_popup_toolbar_menu (GdkEventButton *event)
 
 }
 
+/* Now leaving Hack City */
+#undef _
+#define _(x) gettext (x)
+
 static int
 button_press (GtkWidget *dock, GdkEventButton *event, gpointer user_data)
 {
